@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11882 2020-01-19 13:27:40Z Lavender $
+# $Id: __init__.py 11920 2020-02-12 07:55:26Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-01-19 21:27:40 +0800 (週日, 19 一月 2020) $
-# $Revision: 11882 $
+# $Date: 2020-02-12 15:55:26 +0800 (週三, 12 二月 2020) $
+# $Revision: 11920 $
 
 from __future__ import print_function
 
@@ -685,11 +685,23 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
 
     #=========================================================================
     # Django plugins.
+    middleware = [
+        'django.contrib.sessions.middleware.SessionMiddleware',
+        'django.middleware.common.CommonMiddleware',
+        'django.middleware.csrf.CsrfViewMiddleware',
+        'django.contrib.auth.middleware.AuthenticationMiddleware',
+        'django.contrib.messages.middleware.MessageMiddleware',
+        'django.middleware.clickjacking.XFrameOptionsMiddleware',
+        'django.middleware.security.SecurityMiddleware',
+    ]
     if DJANGO_VERSION >= 11100: # django >= 1.11
         MIDDLEWARE = 'MIDDLEWARE'
     else:
         MIDDLEWARE = 'MIDDLEWARE_CLASSES'
         
+    if not DJANGO_VERSION >= 20000: # django < 2.0
+        middleware.append('django.contrib.auth.middleware.SessionAuthenticationMiddleware')
+        
     pluginsDefaults = {
         'INSTALLED_APPS': (
             'django.contrib.admin',
@@ -704,16 +716,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
             'Iuno.deploy',
             'Iuno.member',
         ),
-        MIDDLEWARE: (
-            'django.contrib.sessions.middleware.SessionMiddleware',
-            'django.middleware.common.CommonMiddleware',
-            'django.middleware.csrf.CsrfViewMiddleware',
-            'django.contrib.auth.middleware.AuthenticationMiddleware',
-            'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
-            'django.contrib.messages.middleware.MessageMiddleware',
-            'django.middleware.clickjacking.XFrameOptionsMiddleware',
-            'django.middleware.security.SecurityMiddleware',
-        )
+        MIDDLEWARE: middleware,
     }
     
     if warns:
