@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11894 2020-02-04 12:08:11Z Lavender $
+# $Id: __init__.py 11932 2020-02-18 17:50:41Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-02-04 20:08:11 +0800 (週二, 04 二月 2020) $
-# $Revision: 11894 $
+# $Date: 2020-02-19 01:50:41 +0800 (週三, 19 二月 2020) $
+# $Revision: 11932 $
 
 import os
 import sys
@@ -337,6 +337,13 @@ def attachSettings(settingsDict, enablePaypal=False):
     #=========================================================================
 
     #=========================================================================
+    # payment
+    defaultSettings = {
+        'SESSION_COOKIE_SAMESITE' : None,
+    }
+
+    update(settingsDict, defaultSettings)
+    
     ecpayEnable = False
     if 'IUNO_SHOP_ECPAY_ENABLE' in settingsDict:
         ecpayEnable = settingsDict['IUNO_SHOP_ECPAY_ENABLE']
@@ -367,6 +374,10 @@ def attachSettings(settingsDict, enablePaypal=False):
            
         ]
     }
+    
+    def accessFunction(user, urlName, urlArgs, urlKwargs):
+        return user.is_staff
+
 
     if enablePaypal:
         require('PAYPAL_API_USERNAME', settingsDict)
@@ -388,43 +399,37 @@ def attachSettings(settingsDict, enablePaypal=False):
         ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
             'label': _('Paypal transactions'),
             'url_name': 'paypal-express-list',
-            'access_fn': \
-                lambda user, url_name, url_args, url_kwargs: user.is_staff,
+            'access_fn': accessFunction,
         })
-
+        
     if ecpayEnable:
         ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
             'label': _('ECPay transactions'),
             'url_name': 'ecpayTransaction',
-            'access_fn': \
-                lambda user, url_name, url_args, url_kwargs: user.is_staff,
+            'access_fn': accessFunction,
         })
         ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
             'label': _('ECPay logistic transactions'),
             'url_name': 'ecpayLogisticTransaction',
-            'access_fn': \
-                lambda user, url_name, url_args, url_kwargs: user.is_staff,
+            'access_fn': accessFunction,
         })
     if allpayEnable:
         ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
             'label': _('AllPay transactions'),
             'url_name': 'allpayTransaction',
-            'access_fn': \
-                lambda user, url_name, url_args, url_kwargs: user.is_staff,
+            'access_fn': accessFunction,
         })
     if spgatewayEnable:
         ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
             'label': _('Spgateway transactions'),
             'url_name': 'spgatewayTransaction',
-            'access_fn': \
-                lambda user, url_name, url_args, url_kwargs: user.is_staff,
+            'access_fn': accessFunction,
         })
     if cathaybkEnable:
         ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
             'label': _('Cathay credit transactions'),
             'url_name': 'cathaybkCreditTransaction',
-            'access_fn': \
-                lambda user, url_name, url_args, url_kwargs: user.is_staff,
+            'access_fn': accessFunction,
         })
 
     if enablePaypal or ecpayEnable or allpayEnable or spgatewayEnable:
@@ -445,8 +450,7 @@ def attachSettings(settingsDict, enablePaypal=False):
             s['children'].append({
                 'label': _('Bonus settings'),
                 'url_name': 'bonusSettings',
-                'access_fn': \
-                    lambda user, url_name, url_args, url_kwargs: user.is_staff,
+                'access_fn': accessFunction,
             })
     #=========================================================================
     
@@ -631,7 +635,12 @@ def attachShopURLs(settings, urlpatterns):
             url(r'^shop/dashboard/catalogue'
                 r'/products/(?P<pk>\d+)/(?P<action>.*)/$', 
                 staff_member_required(views.ProductPublicView.as_view()),
-                name='dashboardProductPublic')
+                name='dashboardProductPublic'),
+            # promotions
+            url(r'^shop/', include(apps.get_app_config('promotions').urls[0])),
+            
+            # dashboard_promotions
+            url(r'^shop/dashboard/content-blocks/', include(apps.get_app_config('dashboard_promotions').urls[0])),
         )
     else:
         from oscar.app import application as shop
