@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11930 2020-02-18 16:03:26Z Lavender $
+# $Id: views.py 11945 2020-02-21 11:10:48Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-02-19 01:03:26 +0900 (週三, 19 二月 2020) $
-# $Revision: 11930 $ 
+# $Date: 2020-02-21 19:10:48 +0800 (週五, 21 二月 2020) $
+# $Revision: 11945 $ 
 
 import json
 import logging
@@ -299,20 +299,16 @@ def placeOrder(self, basket, total,  # noqa (too complex (12))
             if bonusVoucher:
                 if len(bonusVoucher.code.split("-")) == 4: 
                     use = int(bonusVoucher.code.split("-")[1])
+                    
+            # update use
+            b.quantity = b.quantity - use
+            b.save()
             
             if config.receiveStatus == settings.OSCAR_INITIAL_ORDER_STATUS:
-                # update
-                b.quantity = b.quantity + receive - use
+                # update receive
+                b.quantity = b.quantity + receive
                 b.save()
                 
-                # record
-                record = BonusRecord.objects.create(
-                    user=user,
-                    order=order,
-                    use=use,
-                    receive=receive,
-                )
-                
                 messages.info(
                     request, _("You earn %d bonus on this order.") % receive)
             else:
@@ -320,6 +316,15 @@ def placeOrder(self, basket, total,  # noqa (too complex (12))
                     request, 
                     _("When you do complete the order transaction, "
                       "you will earn %d bonus on this order.") % receive)
+                receive = 0 # 只先記錄 use 的部分
+                      
+            # record
+            record = BonusRecord.objects.create(
+                user=user,
+                order=order,
+                use=use,
+                receive=receive,
+            )
             
         
             
@@ -505,7 +510,7 @@ def handle_order_status_change(self, order, new_status, note_msg=None):
         record = BonusRecord.objects.create(
             user=user,
             order=order,
-            use=use,
+            use=0, # 已在購買訂單時紀錄
             receive=receive,
         )
 
@@ -1933,16 +1938,6 @@ class ProductTable(tables.ProductTable):
 catalogueViews.ProductListView.table_class = ProductTable
 
 
-# custom shop dashboard user detail template (add phone number info)
-dashboardUsersViews.UserDetailView.template_name = (
-    'shop/dashboard/users/detail.html'
-)
-    
-# custom shop dashboard order detail template (add phone number info)
-dashboardOrderViews.OrderDetailView.template_name = (
-    'shop/dashboard/orders/order_detail.html'
-)
-
         
     
 
